#!/bin/bash

# this script move data from current mysql to the new mysql, and update the performance configuration file
# please note, the user defined in /etc/cpbx/apply_patches.conf MUST be able to create users and database on the new server.
# this script will: 
# 1. read current performance conf
# 2. dump current database
# 3. read apply_patches.conf
# 4. restore databse on external server
# 5. edit performance conf to match apply_patches


function showError() {
  echo "Error : $1"
  exit 1
}

echo "Reading local configuration"
# Step 1: get database config from performance conf file.
dos2unix /etc/performance/Settings.php
CURRENT_DBHOST=`cat /etc/performance/Settings.php | grep "MYSQL_HOST" | cut -d '=' -f 2 | tr -d \" | tr -d ";" | xargs`
CURRENT_DBPORT=`cat /etc/performance/Settings.php | grep "MYSQL_PORT" | cut -d '=' -f 2 | tr -d \" | tr -d ";" | xargs`
CURRENT_DBUSER=`cat /etc/performance/Settings.php | grep "MYSQL_USER" | cut -d '=' -f 2 | tr -d \" | tr -d ";" | xargs`
CURRENT_DBPASSWORD=`cat /etc/performance/Settings.php | grep "MYSQL_PASSWORD" | cut -d '=' -f 2 | tr -d \" | tr -d ";" | xargs`
# When using localhost, fallback to root user without password
if [ "$CURRENT_DBHOST" = "127.0.0.1" ] || [ "$CURRENT_DBHOST" = "localhost" ]
then
  echo "Localhost used, falling back to root user for DB authentication"
  CURRENT_DBUSER="root"
  CURRENT_DBPASSWORD=""
fi
if [ "$CURRENT_DBPASSWORD" != "" ]
then
  CURRENT_MYSQLDUMPCMD="mysqldump -h $CURRENT_DBHOST -P $CURRENT_DBPORT -u $CURRENT_DBUSER -p$CURRENT_DBPASSWORD"
  echo "Mysql host is $CURRENT_DBHOST:$CURRENT_DBPORT, using user $CURRENT_DBUSER with password $CURRENT_DBPASSWORD"
else
  CURRENT_MYSQLDUMPCMD="mysqldump -h $CURRENT_DBHOST -P $CURRENT_DBPORT -u $CURRENT_DBUSER"
  echo "Mysql host is $CURRENT_DBHOST:$CURRENT_DBPORT, using user $CURRENT_DBUSER"
fi

# Step 2: dump database
echo "Dumping locale database"
DUMPFILE=`mktemp`
$CURRENT_MYSQLDUMPCMD --databases performance > $DUMPFILE
if [ "$?" != "0" ]
then
  showError "Step 2: error during dump"
fi

# Step 3: read apply_patches configuration file
echo "Reading distant configuration"
NEW_DBHOST=`cat /etc/cpbx/apply_patches.conf | grep "hostname" | cut -d '=' -f 2 | xargs`
NEW_DBUSER=`cat /etc/cpbx/apply_patches.conf | grep "username" | cut -d '=' -f 2 | xargs`
NEW_DBPASSWORD=`cat /etc/cpbx/apply_patches.conf | grep "password" | cut -d '=' -f 2 | xargs`
if [ "$NEW_DBHOST" == "" ] || [ "$NEW_DBUSER" == "" ] || [ "$NEW_DBPASSWORD" == "" ]
then
  showError "Step 3: Invalid configuration found"
fi
echo "Distant Mysql host is $NEW_DBHOST, using user $NEW_DBUSER with password $NEW_DBPASSWORD"

# Step 4: restore the db on the new server
echo "Restoring data to distant server"
mysql -h $NEW_DBHOST -u $NEW_DBUSER -p$NEW_DBPASSWORD < $DUMPFILE
if [ "$?" != "0" ]
then
  showError "Step 4: error during restore"
fi

# Step 5 : Edit amiserv conf
echo "Editing locale configuration file"
if [ -f /etc/performance/Settings.php.bak ]
then
  rm -f /etc/performance/Settings.php.bak
fi
cp /etc/performance/Settings.php /etc/performance/Settings.php.bak
sed -i "s/^.*MYSQL_HOST.*/public static \$MYSQL_HOST = \"$NEW_DBHOST\";/" /etc/performance/Settings.php


# Step 6 : create user on external server
echo "Creating DB User"
mysql -h $NEW_DBHOST -u $NEW_DBUSER -p$NEW_DBPASSWORD <<EOF
GRANT ALL ON performance.* TO 'performance'@'localhost' IDENTIFIED BY '54s4f4zvsqehbgcx';
GRANT ALL ON performance.* TO 'performance'@'127.0.0.1' IDENTIFIED BY '54s4f4zvsqehbgcx';
GRANT ALL ON performance.* TO 'performance'@'::1' IDENTIFIED BY '54s4f4zvsqehbgcx';
GRANT ALL ON performance.* TO 'performance'@'%' IDENTIFIED BY '54s4f4zvsqehbgcx';
FLUSH PRIVILEGES;
EOF

echo "Finished"
exit 0